@@ -6,7 +6,7 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -129,6 +129,7 @@ sub add_result {
 		$data{route_start} = $e_ar->getAttribute('pde');
 		$data{transfer}    = $e_ar->getAttribute('tra');
 		$data{arrival_wings} = $e_ar->getAttribute('wings');
+		$data{unk_ar_hi}     = $e_ar->getAttribute('hi');
 	}
 
 	if ($e_dp) {
@@ -138,6 +139,7 @@ sub add_result {
 		$data{route_end}    = $e_dp->getAttribute('pde');
 		$data{transfer}     = $e_dp->getAttribute('tra');
 		$data{departure_wings} = $e_dp->getAttribute('wings');
+		$data{unk_dp_hi}       = $e_dp->getAttribute('hi');
 	}
 
 	my $result = Travel::Status::DE::IRIS::Result->new(%data);
@@ -224,7 +226,9 @@ sub get_realtime {
 			my $msgid = $e_m->getAttribute('id');
 			my $ts    = $e_m->getAttribute('ts');
 
-			if ($value) {
+			# 0 and 1 (with key "f") are related to canceled trains and
+			# do not appear to hold information
+			if ( defined $value and $value > 1 ) {
 				$messages{$msgid} = [ $ts, $type, $value ];
 			}
 		}
@@ -254,19 +258,22 @@ sub get_realtime {
 		if ($e_ar) {
 			$result->add_ar(
 				arrival_ts      => $e_ar->getAttribute('ct'),
+				plan_arrivaL_ts => $e_ar->getAttribute('pt'),
 				platform        => $e_ar->getAttribute('cp'),
 				route_pre       => $e_ar->getAttribute('cpth'),
 				sched_route_pre => $e_ar->getAttribute('ppth'),
 				status          => $e_ar->getAttribute('cs'),
+				status_since    => $e_ar->getAttribute('clt'),
 			);
 		}
 		if ($e_dp) {
 			$result->add_dp(
-				departure_ts     => $e_dp->getAttribute('ct'),
-				platform         => $e_dp->getAttribute('cp'),
-				route_post       => $e_dp->getAttribute('cpth'),
-				sched_route_post => $e_dp->getAttribute('ppth'),
-				status           => $e_dp->getAttribute('cs'),
+				departure_ts      => $e_dp->getAttribute('ct'),
+				plan_departure_ts => $e_dp->getAttribute('pt'),
+				platform          => $e_dp->getAttribute('cp'),
+				route_post        => $e_dp->getAttribute('cpth'),
+				sched_route_post  => $e_dp->getAttribute('ppth'),
+				status            => $e_dp->getAttribute('cs'),
 			);
 		}
 
@@ -320,7 +327,7 @@ Travel::Status::DE::IRIS - Interface to IRIS based web departure monitors.
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -419,7 +426,7 @@ Travel::Status::DE::IRIS::Stations(3pm)
 
 =head1 AUTHOR
 
-Copyright (C) 2013-2014 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2013-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
