@@ -14,7 +14,7 @@ use DateTime::Format::Strptime;
 use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 Travel::Status::DE::IRIS::Result->mk_ro_accessors(
 	qw(arrival classes date datetime delay departure is_cancelled is_transfer
@@ -102,6 +102,13 @@ sub add_ar {
 		time_zone => 'Europe/Berlin',
 	);
 
+	# unscheduled arrivals may not appear in the plan, but we do need to
+	# know their planned arrival time
+	if ( $attrib{plan_arrival_ts} ) {
+		$self->{sched_arrival}
+		  = $strp->parse_datetime( $attrib{plan_arrival_ts} );
+	}
+
 	if ( $attrib{arrival_ts} ) {
 		$self->{arrival} = $strp->parse_datetime( $attrib{arrival_ts} );
 		$self->{delay}
@@ -139,6 +146,13 @@ sub add_dp {
 		time_zone => 'Europe/Berlin',
 	);
 
+	# unscheduled arrivals may not appear in the plan, but we do need to
+	# know their planned arrival time
+	if ( $attrib{plan_departure_ts} ) {
+		$self->{sched_departure}
+		  = $strp->parse_datetime( $attrib{plan_departure_ts} );
+	}
+
 	if ( $attrib{departure_ts} ) {
 		$self->{departure} = $strp->parse_datetime( $attrib{departure_ts} );
 		$self->{delay}
@@ -322,7 +336,7 @@ sub qos_messages {
 	);
 
 	my @keys = sort keys %{ $self->{messages} };
-	my @msgs = grep { $_->[1] eq 'q' } map { $self->{messages}{$_} } @keys;
+	my @msgs = grep { $_->[1] ~~ [qw[f q]] } map { $self->{messages}{$_} } @keys;
 	my @ret;
 
 	for my $msg (@msgs) {
@@ -532,12 +546,19 @@ sub translate_msg {
 		46 => 'Warten auf freie Einfahrt',
 		47 => 'Verspätete Bereitstellung',
 		48 => 'Verspätung aus vorheriger Fahrt',
-		64 => 'Weichenstörung',
 		55 => 'Technische Störung an einem anderen Zug',        # ?
-		57 => 'Zusätzlicher Halt',                              # ?
-		58 => 'Umleitung(?)',                                    # ?
+		56 => 'Warten auf Fahrgäste aus einem Bus',
+		57 => 'Zusätzlicher Halt',
+		58 => 'Umleitung',                                       # ?
+		59 => 'Schnee und Eis',
+		61 => 'Türstörung',
 		62 => 'Behobene technische Störung am Zug',
 		63 => 'Technische Untersuchung am Zug',
+		64 => 'Weichenstörung',
+		65 => 'Erdrutsch',
+		73 => 'Mehrzweckabteil vorne',
+		74 => 'Mehrzweckabteil hinten',
+		77 => 'Ohne 1. Klasse',
 		80 => 'Abweichende Wagenreihung',
 		82 => 'Mehrere Wagen fehlen',
 		83 => 'Fehlender Zugteil',
@@ -592,7 +613,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -975,16 +996,27 @@ Source: Correlation between IRIS and DB RIS (bahn.de).
 
 Source: Correlation between IRIS and DB RIS (bahn.de).
 
+=item d 56 : "Warten auf FahrgE<auml>ste aus einem Bus"
+
+Source: Correlation between IRIS and DB RIS (bahn.de).
+
 =item d 57 : "ZusE<auml>tzlicher Halt"
 
-Source: Correlation between IRIS and DB RIS (bahn.de). Only one entry so far,
-so may be wrong.
+Source: Correlation between IRIS and DB RIS (bahn.de).
 
 =item d 58 : "Umleitung"
 
 Source: Correlation between IRIS and DB RIS (bahn.de). Several entries, related
 to "Notarzteinsatz am Gleis".
 
+=item d 59 : "Schnee und Eis"
+
+Source: Correlation between IRIS and DB RIS (bahn.de).
+
+=item d 61 : "TE<uuml>rstE<ouml>rung"
+
+Source: Correlation between IRIS and DB RIS (bahn.de).
+
 =item d 62 : "Behobene technische StE<ouml>rung am Zug"
 
 Source: Correlation between IRIS and DB RIS (bahn.de).
@@ -995,6 +1027,22 @@ Source: Correlation between IRIS and DB RIS (bahn.de).
 
 Source: correlation between IRIS and DB RIS (bahn.de).
 
+=item d 65 : "Erdrutsch"
+
+Source: correlation between IRIS and DB RIS (bahn.de).
+
+=item q 73 : "Mehrzweckabteil vorne"
+
+Source: correlation between IRIS and DB RIS (bahn.de).
+
+=item q 74 : "Mehrzweckabteil hinten"
+
+Source: correlation between IRIS and DB RIS (bahn.de).
+
+=item q 77 : "Ohne 1. Klasse"
+
+Source: correlation between IRIS and DB RIS (bahn.de).
+
 =item q 80 : "Abweichende Wagenreihung"
 
 Verified by L<https://iris.noncd.db.de/irisWebclient/Configuration>.
@@ -1103,7 +1151,7 @@ Travel::Status::DE::IRIS(3pm).
 
 =head1 AUTHOR
 
-Copyright (C) 2013-2014 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2013-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
